### License Info

This program is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
Public License for more details.

Please check <http://www.gnu.org/licenses/>.

Introduction
============

The present script takes the output of our Footprint-based analysis and
matches the results againts a file containing an harmonised list of
drug-targets from DrugBank, clinical trials and also INDRA and AILANI
results.

    library(DT)
    library(dplyr)

Results
=======

Reading Input files
-------------------

We first read the harmonised list of drug-target interactions

    drug_target <- read.delim("InputFiles/harmonised_drugs_mirnas_ups.tsv")

We then read the output of our Footprint-based analyisis, namely
CARNIVAL's output network. This file can be found
[here](https://gitlab.lcsb.uni.lu/computational-modelling-and-simulation/footprint-based-analysis-and-causal-network-contextualisation-in-sars-cov-2-infected-a549-cell-line/-/tree/master/Carnival_Results).

    carnival_results <- readRDS("InputFiles/carnival_results_withprogeny.rds")
    carnival_nodes_hgnc <- unique(c(carnival_results$weightedSIF[,"Node1"], carnival_results$weightedSIF[,"Node2"]))

Matching the results
--------------------

We finally match all our genes from the carnival network with all the
genes from the different pathways included in the COVID19 Disease maps.

    match_drug_target <- drug_target %>% 
      dplyr::filter(target_symbol %in% carnival_nodes_hgnc)

and We visualize the results.

    datatable(match_drug_target)

<!--html_preserve-->

<script type="application/json" data-for="htmlwidget-2a3bf57180af99c1046e">{"x":{"filter":"none","vertical":false,"data":[["1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19","20","21","22","23","24","25","26","27","28","29","30","31","32","33","34","35","36","37","38","39","40","41","42","43","44","45","46","47","48","49","50","51","52","53","54","55","56","57","58","59","60","61","62","63","64","65","66","67","68","69","70","71","72","73","74","75","76","77","78","79","80","81","82","83","84","85","86","87","88","89","90","91","92","93","94","95","96","97","98","99","100","101","102","103","104","105","106","107","108","109","110","111","112","113","114","115","116","117","118","119","120","121","122","123","124","125","126","127","128","129","130","131","132","133","134","135","136","137","138","139","140","141","142","143","144","145","146","147","148","149","150","151","152","153","154","155","156","157","158","159","160","161","162","163","164","165","166","167","168","169","170","171","172","173","174","175","176","177","178","179","180","181","182","183","184","185","186","187","188","189","190","191","192","193","194","195","196","197","198","199","200","201","202","203","204","205","206","207","208","209","210","211","212","213","214","215","216","217","218","219","220","221","222","223","224","225","226","227","228","229","230","231","232","233","234","235","236","237","238","239","240","241","242","243","244","245","246","247","248","249","250","251","252","253","254","255","256","257","258","259","260","261","262","263","264","265","266","267","268","269","270","271","272","273","274","275","276","277","278","279","280","281","282","283","284","285","286","287","288","289","290","291","292","293","294","295","296","297","298","299","300","301","302","303","304","305","306","307","308","309","310","311","312","313","314","315","316","317","318","319","320","321","322","323","324","325","326","327","328","329","330","331","332","333","334","335","336","337","338","339","340","341","342","343","344","345","346","347","348","349","350","351","352","353","354","355","356","357","358","359","360","361","362","363","364","365","366","367","368","369","370","371","372","373","374","375","376","377","378","379","380","381","382","383","384","385","386","387","388","389","390","391","392","393","394","395","396","397","398","399","400","401","402","403","404","405","406","407","408","409","410","411","412","413","414","415","416","417","418","419","420","421","422","423","424","425","426","427","428","429","430","431","432","433","434","435","436","437","438","439","440","441","442","443","444","445","446","447","448","449","450","451","452","453","454","455","456","457","458","459","460","461","462","463","464","465","466","467","468","469","470","471","472","473","474","475","476","477","478","479","480","481","482","483","484","485","486","487","488","489","490","491","492","493","494","495","496","497","498","499","500","501","502","503","504","505","506","507","508","509","510","511","512","513","514","515","516","517","518","519","520","521","522","523","524","525","526","527","528","529","530","531","532","533","534","535","536","537","538","539","540","541","542","543","544","545","546","547","548","549","550","551","552","553","554","555","556","557","558","559","560","561","562","563","564","565","566","567","568","569","570","571","572","573","574","575","576","577","578","579","580","581","582","583","584","585","586","587","588","589","590","591","592","593","594","595","596","597","598","599","600","601","602","603","604","605","606","607","608","609","610","611","612","613","614","615","616","617","618","619","620","621","622","623","624","625","626","627","628","629","630","631","632","633","634","635","636","637","638","639","640","641","642","643","644","645","646","647","648","649","650","651","652","653","654","655","656","657","658","659","660","661","662","663","664","665","666","667","668","669","670","671","672","673","674","675","676","677","678","679","680","681","682","683","684","685","686","687","688","689","690","691","692","693","694","695","696","697","698","699","700","701","702","703","704","705","706","707","708","709","710","711","712","713","714","715","716","717","718","719","720","721","722","723","724","725","726","727","728","729","730","731","732","733","734","735","736","737","738","739","740","741","742","743","744","745","746","747","748","749","750","751","752","753","754","755","756","757","758","759","760","761","762","763","764","765","766","767","768","769","770","771","772","773","774","775","776","777","778","779","780","781","782","783","784","785","786","787","788","789","790","791","792","793","794","795","796","797","798","799","800","801","802","803","804","805","806","807","808","809","810","811","812","813","814","815","816","817","818","819","820","821","822","823","824","825","826","827","828","829","830","831","832","833","834","835","836","837","838","839","840","841","842","843","844","845","846","847","848","849","850","851","852","853","854","855","856","857","858","859","860","861","862","863","864","865","866","867","868","869","870","871","872","873","874","875","876","877","878","879","880","881","882","883","884","885","886","887","888","889","890","891","892","893","894","895","896","897","898","899","900","901","902","903","904","905","906","907","908","909","910","911","912","913","914","915","916","917","918","919","920","921","922","923","924","925","926","927","928","929","930","931","932","933","934","935","936","937","938","939","940","941","942","943","944","945","946","947","948","949","950","951","952","953","954","955","956","957","958","959","960","961","962","963","964","965","966","967","968","969","970","971","972","973","974","975","976","977","978","979","980","981","982","983","984","985","986","987","988","989","990","991","992","993","994","995","996","997","998","999","1000","1001","1002","1003","1004","1005","1006","1007","1008","1009","1010","1011","1012","1013","1014","1015","1016","1017","1018","1019","1020","1021","1022","1023","1024","1025","1026","1027","1028","1029","1030","1031","1032","1033","1034","1035","1036","1037","1038","1039","1040","1041","1042","1043","1044","1045","1046","1047","1048","1049","1050","1051","1052","1053","1054","1055","1056","1057","1058","1059","1060","1061","1062","1063","1064","1065","1066","1067","1068","1069","1070","1071","1072","1073","1074","1075","1076","1077","1078","1079","1080","1081","1082","1083","1084","1085","1086","1087","1088","1089","1090","1091","1092","1093","1094","1095","1096","1097","1098","1099","1100","1101","1102","1103","1104","1105","1106","1107","1108","1109","1110","1111","1112","1113","1114","1115","1116","1117","1118","1119","1120","1121","1122","1123","1124","1125","1126","1127","1128","1129","1130","1131","1132","1133","1134","1135","1136","1137","1138","1139","1140","1141","1142","1143","1144","1145","1146","1147","1148","1149","1150","1151","1152","1153","1154","1155","1156","1157","1158","1159","1160","1161","1162","1163","1164","1165","1166","1167","1168","1169","1170","1171"],["EGFR","EGFR","E2F4","E2F4","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","IRF3","IRF3","IRF3","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","MBTPS1","MBTPS1","MBTPS1","MBTPS1","MBTPS1","MBTPS1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","ATF6","ATF4","MAPK3","MAPK3","MAPK3","MAPK3","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","MBTPS1","MBTPS1","MBTPS1","ATF4","ATF4","ATF4","MAPK11","MAPK11","MAPK11","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TICAM1","TICAM1","MAPK3","MAPK3","MAPK3","MAPK3","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","IKBKE","IKBKE","IKBKE","IRF3","SIRT1","IGF1","MAPK3","EGFR","EGFR","MAPK3","IRF3","EGFR","MAPKAPK2","REL","IRF3","EGFR","SIRT1","EP300","APC","CCND1","EGFR","IKBKE","EGFR","IKBKE","EGFR","EGFR","SIRT1","TICAM1","IRF3","TBK1","ATF6","MAPKAPK2","EGFR","IRF3","MAPK3","EGFR","SIRT1","CDK1","SIRT1","ATF6","TBK1","IGF1","TBK1","TICAM1","CDK4","TBK1","IRF3","BRCA1","CDK1","EGFR","EGFR","CDK1","ATF6","CDK1","EP300","ATM","CDK4","IKBKE","TBK1","IRF3","TBK1","IRF3","IKBKE","TBK1","EGFR","SMAD4","CDK1","RUNX1","EGFR","EGFR","ATF4","TBK1","CREBBP","EP300","TBK1","TICAM1","IRF3","IRF3","REL","SIRT1","IRF3","BRCA1","IRF3","EGFR","IRF3","CCND1","TICAM1","MAPK3","IRF3","MAPK1","BRCA1","IRF3","EP300","ATF4","EGFR","EGFR","EGFR","SMAD4","MAPK3","CREBBP","EGFR","BRCA1","EGFR","EGFR","MAPK3","ATF4","ATF6","ATF4","SMAD4","IGF1","PIK3CA","SIRT1","TICAM1","EGFR","RUNX1","EGFR","MAPK3","IRF3","ATF4","ATM","IRF3","TBK1","IGF1","IRF3","IRF3","MTA1","IRF3","SOX2","IRF3","EGFR","IRF3","TBK1","SREBF1","IRF3","TBK1","CREBBP","CREBBP","IKBKE","ATF4","IGF1","IRF3","SIRT1","IRF3","IRF3","ATM","EGFR","SIRT1","IRF3","EGFR","IRF3","ATM","IRF3","SMAD4","SMAD4","SMAD4","REL","IRF3","MAPK1","MAPK7","MAPK3","MAPKAPK2","MEF2A","EGFR","MAPK3","SOX2","EGFR","CDK4","TBK1","TICAM1","IRF3","MTA1","ATM","IRF3","IRF3","ATF6","RBPJ","BRCA1","MAPK3","MAPK1","ATF4","MEF2A","BRCA1","MAPK3","CCND1","IRF3","IRF3","TBK1","ATM","SIRT1","EGFR","IRF3","ATF4","IRF3","SOX2","IRF3","TICAM1","IRF3","IRF3","EGFR","SREBF1","EGFR","SMAD4","MAPK3","IRF3","IRF3","TEAD1","EGFR","ATF6","ATF6","ATF6","SMAD1","SMAD4","TBK1","SIRT1","IRF3","RUNX1","ZEB2","TBK1","IRF3","ATF6","SREBF1","ATF6","IRF3","CCND1","SREBF1","RUNX1","SREBF1","SIRT1","IRF3","RUNX2","SOX2","ZEB2","SREBF1","EGFR","TP53BP1","ATF4","TICAM1","ATF4","SIRT1","CDK1","EP300","RUNX2","SOX2","IGF1","SIRT1","RBPJ","IGF1","IGF1","IRF3","IRF3","RUNX2","RUNX2","NUP98","RUNX2","IGF1","SIRT1","RUNX2","SOX2","RUNX2","IRF3","MAPK3","RUNX1","IRF3","MAPK3","CDK1","IGF1","IRF3","TBK1","CDK1","TBK1","IRF3","IGF1","MAPK3","IRF3","IRF3","EGFR","IRF3","EGFR","YAP1","TBK1","IGF1","RUNX2","EGFR","SMAD4","TICAM1","IRF3","EGFR","EGFR","CDK4","CDK1","CDK4","CDK4","IRF3","ATF6","TBK1","IRF3","CREBBP","BRCA1","IRF3","EGFR","CREBBP","BRCA1","TP53BP1","IRF3","TBK1","IKBKE","TICAM1","SIRT1","MAPK1","MAPK3","LRP6","EGFR","IRF3","IRF3","IRF3","MAPK3","MAPK1","MAPK3","CDK4","ATF6","SREBF1","ATF4","IGF1","CCND1","EP300","EGFR","IGF1","IGF1","NCOR1","IGF1","IRF3","RUNX2","CDK4","EGFR","SIRT1","SIRT1","SMAD4","IRF3","REL","CREBBP","CREBBP","IRF3","ATM","MAPKAPK2","TBK1","EGFR","CCND1","TBK1","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","ZEB2","NUP98","IRF3","IKBKE","IRF3","TBK1","TICAM1","IRF3","CDK4","IRF3","TBK1","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","ATF6","MBTPS1","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","MAPK11","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","MAPK3","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","SMAD1","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF4","ATF6","ATF6","CCND1","CDK1","CREBBP","EGFR","EGFR","EGFR","EGFR","EP300","IGF1","IGF1","IGF1","IGF1","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IKBKE","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","IRF3","MAPK1","MAPK1","MAPK3","MAPK3","MAPK3","MAPK3","PRKAA1","SIRT1","SIRT1","SIRT1","SMO","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TBK1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1","TICAM1"],["zanubrutinib","abivertinib","threonine","vitamin c","sb 203580","doramapimod","vx-745","sb-202190","[11c]-sorafenib","pcid:5353940","nitrate","(+)-abscisic acid","reactive oxygen species","resveratrol","tyrphostin ag 1478","tamoxifen","genistein","sorafenib","u0126","2-(2-amino-3-methoxyphenyl)chromen-4-one","3',5'-cyclic amp","atp","staurosporine","n-[3-[[5-iodo-4-[3-[[oxo(thiophen-2-yl)methyl]amino]propylamino]-2-pyrimidinyl]amino]phenyl]-1-pyrrolidinecarboxamide","amlexanox","n-[3-[[5-cyclopropyl-2-[3-(4-morpholinylmethyl)anilino]-4-pyrimidinyl]amino]propyl]cyclobutanecarboxamide","sunitinib","sunitinib malate","resveratrol","thymoquinone","cholesterol","glucose","glucocorticoid","lipopolysaccharide","double-stranded rna","curcumin","amlexanox","n-[3-[[5-cyclopropyl-2-[3-(4-morpholinylmethyl)anilino]-4-pyrimidinyl]amino]propyl]cyclobutanecarboxamide","n-[3-[[5-iodo-4-[3-[[oxo(thiophen-2-yl)methyl]amino]propylamino]-2-pyrimidinyl]amino]phenyl]-1-pyrrolidinecarboxamide","sunitinib malate","sunitinib","4-(n-nitrosomethylamino)-1-(3-pyridyl)butan-1-one","silver(1+)","nickel(2+)","gly-asn","1,10-phenanthroline","arg-leu","melatonin","ethanol","fluoride","glucose","sorafenib","lipopolysaccharide","glucose","tomatidine","ursolic acid","sirolimus","lipopolysaccharide","resveratrol","curcumin","hexadecanoic acid","seaborgium atom","3,4-dichloroisocoumarin","antagonist","fingolimod hydrochloride","sb 203580","sb202190","acetylsalicylic acid","imatinib methanesulfonate","dorsomorphin","ethanol","lipopolysaccharide","melatonin","pseudoephedrine","pseudoephedrine","sulindac","arsenic trioxide","purvalanol","5-iodotubercidin","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","RIPK1","BDNF","BDNF","SHC1","BRAF","SP1","SRF","STAT2","STAT3","STAT3","STAT3","SYT1","TGFA","TGFB1","TGFB1","THBD","TIA1","TLR2","TLR3","TLR3","TLR4","TLR4","TLR5","TNF","TNF","TP53","TPR","HSP90B1","TRAF6","TXN","UBE2N","WNT4","MCOLN3","ACE2","FBXW8","ADIPOQ","CALR","PINK1","CAV1","TLR7","TLR9","CCND1","ZBP1","ZBP1","CHEK2","CHEK2","SHC4","CD9","CDK1","GOPC","CDK2","CDK4","CDKN2A","CDKN2D","TICAM1","RNF41","RNF41","DDX41","DDX41","IFIH1","IFIH1","ADAM10","DDX58","CHEK1","SIN3A","SOCS1","ADAM17","EIF2AK4","CHUK","CHUK","CHUK","TRAM1","TRAM1","TRAM1","TICAM2","DIABLO","KEAP1","ZC3HAV1","BRCC3","CSE1L","EPS15L1","CUL3","DDIT3","DDX1","NAMPT","MIB2","DUSP6","EGFR","EGFR","EGR1","EIF2S2","EIF4E","ELANE","AGT","AGT","AGT","EP300","EPS15","ERBB2","ERBB2","ERBB3","ERN1","ERN1","ERN1","MTOR","GDF2","GHR","ALK","GRN","CXCL1","CXCL1","HIF1A","HIF1A","HMGB1","HSPA5","HSPA5","KAT5","NOD2","IFNB1","IGF1R","IKBKB","IKBKG","IL17A","IL1B","IL6","IL6","CXCL8","CXCL8","INPP5D","INS","IRAK1","IRF1","IRF1","IRF3","IRF7","IRF7","IRS1","JUN","KLKB1","KPNA3","KPNA4","AR","AREG","LEP","TRIM23","RHOA","LTA","LTA","ARHGAP4","SMAD1","SMAD5","SMAD9","MALT1","ARHGEF2","MAP2K1","MAP2K5","MAP3K7","MAPK14","MAPK7","MAS1","MIF","MMP2","MMP3","MYC","MYD88","MYD88","MYD88","MYD88","NBN","NFE2L2","ATF2","ATF4","NOTCH1","ATM","NR3C1","NRG1","NUP214","OXT","ATR","PKD1","PKM","PML","POU2F1","PPM1B","PPP1CB","PRKAA1","EIF2AK2","EIF2AK2","EIF2AK2","PRKRA","PRL","PTK2","PTX3","PLAAT4","REN","RET","Angiotensin-2","Angiotensin-2","Angiotensin-2","Angiotensin-2","Klk9","Replicase polyprotein 1a","S","S","8","4a","4b","Bmpr1a","Bmpr1a","Sting1","Camkk1","Zbp1","RUNX1","TWIST1","BRD4","TRIM11","SH2B2","SPHK2","SELENOS","TRIM59","FUS","HSPE1","FURIN","PTEN","PTGS2","RNA-directed RNA polymerase","BMP2","SOX2","STAT3","FAS","TNFSF11","LAT2","PARK7","TIRAP","TICAM1","CPN1","TOR1A","EP300","FGF2","FOXO1","MTOR","IGF1","RBPJ","IL10","IL1B","LTF","MAPK3","ARNTL","MMP2","NUP98","PTH","PTH","Angiotensin-2","RUNX2","SRPK1","STAT1","STAT1","STK3","HNF1A","TNF","TNF","TP53","TP53","C1QBP","USP7","WEE1","C6","C6","ADIPOQ","ADIPOQ","RTN4","CASP8","CBL","TLR9","ERBIN","YAP1","TRIM11","FBXO32","SMURF1","STAMBP","WWP1","SARM1","SYNE1","LRIG1","CDH1","CDK4","CDKN1B","CDKN2A","SUB1","FIS1","CP","OTUB1","OTUB1","CREBBP","E2F7","CSH1","CSK","CREBZF","CTBP1","CTSL","CYLD","SIKE1","SIKE1","SIKE1","PARP1","PARP1","PARP1","DKK1","DLG1","DTX4","DNM1L","XRN1","S1PR1","EDN1","EDN1","EEF1E1","EIF2S1","FOXO1","FOXO1","MSTN","GSK3B","HDAC1","IFITM3","IGFBP3","IL6","IL6","INSR","IRF1","KLF4","LTF","LTF","MAP3K11","MAP3K14","NEDD4L","NFKBIA","NFKBIA","NPTX1","NR3C1","NUP214","NUP214","OGT","PRKD1","PRSS1","BAX","PTPN11","RAE1","RELA","TRIM27","Helicase","Uridylate-specific endoribonuclease","ORF4b","1a","rep","S","M","6","N","N","4b","4b","4b","Cdkn2b","6","2a","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","MAF, ","PPP1R15A","TP53","EIF2S1","ATF3, ","ATF4, ","DDIT3, ","NFE2L2, ","CREBBP, ","EIF2A, ","EIF2AK3","HSPA5","EIF2AK3","aspirin","CDKN1A","EGR1","EGFR","TNF","STAT1","CAV1","RELA","INS","TNF","IGF1","Angiotensin-2","CHUK, ","DDX58, ","TRAF3, ","IKBKE, ","IRF3, ","ZC3H12A, ","MAVS, ","STING1, ","TANK, ","CYLD, ","TBK1, ","IKBKG, ","poly i:c, polyinosinic-polycytidylic acid","7a","TLR4","XPO1, ","CHUK","TLR3","TLR2, ","ULK1, ","BCAR3","TOMM70, ","DDX58, ","IFNB1","ISG15","TRIM21, ","MAPK9, ","PTEN","E2F1","IFITM3","EP300, ","FOXO1, ","TRAF2, ","TRAF3, ","PIN1, ","IRF5, ","IKBKE, ","IRF3, ","IFI16","ZC3H12A, ","MAVS, ","8b","STING1, ","TICAM1, ","CREBBP, ","TANK, ","IRF7, ","RBCK1","IFIH1","TLR7","TBK1, ","TRAF6, ","aspirin","MAPK3","MAPK3, ","NRG1","MAP2K1, ","CAV1, ","aspirin","HMOX1","HLA-DMB","SIRT1","PTCH1","TLR4, ","TLR3, ","PRKN, ","USP1, ","DDX58, ","TNF, ","SRC, ","AKT, ","TRIM23, ","MTOR, ","GSK3B, ","TRAF3, ","RIPK1, ","IKBKE, ","IRF3, ","TNIP1, ","IFI16","ZC3H12A, ","MAVS, ","TAX1BP1, ","STING1, ","MIB1, ","TICAM1, ","TANK, ","IRF7, ","CYLD, ","TLR9, ","TBK1, ","DTX4, ","TRAF6, ","IKBKG, ","TLR4, ","TLR3, ","DDX58","TRAF1, ","TRAF3, ","IRF3, ","TBK1, ","UBQLN1, ","TRAF6, "],["drugbank:DB15035","drugbank:DB15327","drugbank:DB00156","drugbank:DB00126","chebi:CHEBI:90705","chebi:CHEBI:40953","chebi:CHEBI:90528","chebi:CHEBI:79090","chembl.compound:CHEMBL1760433","pubchem.compound:5353940","chebi:CHEBI:17632","chebi:CHEBI:2365","chebi:CHEBI:26523","chebi:CHEBI:27881","chebi:CHEBI:75404","chebi:CHEBI:41774","chebi:CHEBI:28088","chebi:CHEBI:50924","chebi:CHEBI:90693","chebi:CHEBI:77954","chebi:CHEBI:17489","chebi:CHEBI:15422","chebi:CHEBI:15738","chebi:CHEBI:91439","chebi:CHEBI:31205","chebi:CHEBI:124930","chebi:CHEBI:38940","chembl.compound:CHEMBL1567","chebi:CHEBI:27881","chebi:CHEBI:113532","chebi:CHEBI:16113","chebi:CHEBI:17234","chebi:CHEBI:24261","chebi:CHEBI:16412","chebi:CHEBI:67208","chebi:CHEBI:3962","chebi:CHEBI:31205","chebi:CHEBI:124930","chebi:CHEBI:91439","chembl.compound:CHEMBL1567","pubchem.compound:3086686","chebi:CHEBI:32692","chebi:CHEBI:49468","chebi:CHEBI:49786","chebi:CHEBI:73888","chebi:CHEBI:44975","chebi:CHEBI:73815","chebi:CHEBI:16796","chebi:CHEBI:16236","chebi:CHEBI:17051","chebi:CHEBI:17234","chebi:CHEBI:50924","chebi:CHEBI:16412","chebi:CHEBI:17234","chebi:CHEBI:9629","chebi:CHEBI:9908","chebi:CHEBI:9168","chebi:CHEBI:16412","chebi:CHEBI:27881","chebi:CHEBI:3962","chebi:CHEBI:15756","chebi:CHEBI:33351","mesh:C046235","chebi:CHEBI:48706","chebi:CHEBI:63112","chebi:CHEBI:90705","pubchem.compound:5353940","chebi:CHEBI:15365","chebi:CHEBI:31690","chebi:CHEBI:78510","chebi:CHEBI:16236","chebi:CHEBI:16412","chebi:CHEBI:16796","drugbank:DB00852","drugbank:DB00852","drugbank:DB00605","drugbank:DB01169","drugbank:DB02733","drugbank:DB04604","mirna:hsa-miR-503-5p","mirna:hsa-miR-424-5p","mirna:hsa-miR-335-5p","mirna:hsa-miR-191-5p","mirna:hsa-miR-199a-5p","mirna:hsa-miR-552-5p","mirna:hsa-miR-6780a-5p","mirna:hsa-miR-6779-5p","mirna:hsa-miR-3689c","mirna:hsa-miR-3689b-3p","mirna:hsa-miR-3689a-3p","mirna:hsa-miR-30b-3p","mirna:hsa-miR-1273h-5p","mirna:hsa-miR-6799-5p","mirna:hsa-miR-6883-5p","mirna:hsa-miR-6785-5p","mirna:hsa-miR-4728-5p","mirna:hsa-miR-149-3p","mirna:hsa-miR-7106-5p","mirna:hsa-miR-6871-5p","mirna:hsa-miR-208b-5p","mirna:hsa-miR-208a-5p","mirna:hsa-miR-7153-3p","mirna:hsa-miR-769-3p","mirna:hsa-miR-193b-3p","mirna:hsa-let-7c-5p","mirna:hsa-miR-214-3p","mirna:hsa-miR-196b-5p","mirna:hsa-miR-342-3p","mirna:hsa-miR-122-5p","mirna:hsa-miR-124-3p","mirna:hsa-let-7a-5p","mirna:hsa-miR-221-3p","mirna:hsa-miR-200c-3p","mirna:hsa-miR-452-5p","mirna:hsa-let-7f-2-3p","mirna:hsa-miR-1185-2-3p","mirna:hsa-miR-1185-1-3p","mirna:hsa-miR-6792-5p","mirna:hsa-miR-3671","mirna:hsa-miR-3674","mirna:hsa-miR-219b-3p","mirna:hsa-miR-4680-3p","mirna:hsa-miR-429","mirna:hsa-miR-4724-5p","mirna:hsa-miR-200b-3p","mirna:hsa-miR-219a-2-3p","mirna:hsa-miR-186-5p","mirna:hsa-miR-3133","mirna:hsa-miR-221-3p","mirna:hsa-miR-193b-3p","mirna:hsa-miR-483-5p","mirna:hsa-miR-320b","mirna:hsa-miR-423-3p","mirna:hsa-miR-34a-5p","mirna:hsa-miR-155-5p","mirna:hsa-miR-26a-5p","mirna:hsa-miR-30a-5p","mirna:hsa-miR-30b-5p","mirna:hsa-miR-30c-5p","mirna:hsa-miR-30d-5p","mirna:hsa-miR-16-5p","mirna:hsa-miR-205-5p","mirna:hsa-miR-675-3p","mirna:hsa-miR-3117-3p","mirna:hsa-miR-216b-5p","mirna:hsa-miR-3591-3p","mirna:hsa-miR-21-3p","mirna:hsa-miR-186-5p","mirna:hsa-miR-155-5p","mirna:hsa-miR-296-5p","mirna:hsa-miR-124-3p","uniprot:Q13546","uniprot:P23560","uniprot:P23560","uniprot:P29353","uniprot:P15056","uniprot:P08047","uniprot:P11831","uniprot:P52630","uniprot:P40763","uniprot:P40763","uniprot:P40763","uniprot:P21579","uniprot:P01135","uniprot:P01137","uniprot:P01137","uniprot:P07204","uniprot:P31483","uniprot:O60603","uniprot:O15455","uniprot:O15455","uniprot:O00206","uniprot:O00206","uniprot:O60602","uniprot:P01375","uniprot:P01375","uniprot:P04637","uniprot:P12270","uniprot:P14625","uniprot:Q9Y4K3","uniprot:P10599","uniprot:P61088","uniprot:P56705","uniprot:Q8TDD5","uniprot:Q9BYF1","uniprot:Q8N3Y1","uniprot:Q15848","uniprot:P27797","uniprot:Q9BXM7","uniprot:Q03135","uniprot:Q9NYK1","uniprot:Q9NR96","uniprot:P24385","uniprot:Q9H171","uniprot:Q9H171","uniprot:O96017","uniprot:O96017","uniprot:Q6S5L8","uniprot:P21926","uniprot:P06493","uniprot:Q9HD26","uniprot:P24941","uniprot:P11802","uniprot:P42771","uniprot:P55273","uniprot:Q8IUC6","uniprot:Q9H4P4","uniprot:Q9H4P4","uniprot:Q9UJV9","uniprot:Q9UJV9","uniprot:Q9BYX4","uniprot:Q9BYX4","uniprot:O14672","uniprot:O95786","uniprot:O14757","uniprot:Q96ST3","uniprot:O15524","uniprot:P78536","uniprot:Q9P2K8","uniprot:O15111","uniprot:O15111","uniprot:O15111","uniprot:Q15629","uniprot:Q15629","uniprot:Q15629","uniprot:Q86XR7","uniprot:Q9NR28","uniprot:Q14145","uniprot:Q7Z2W4","uniprot:P46736","uniprot:P55060","uniprot:Q9UBC2","uniprot:Q13618","uniprot:P35638","uniprot:Q92499","uniprot:P43490","uniprot:Q96AX9","uniprot:Q16828","uniprot:P00533","uniprot:P00533","uniprot:P18146","uniprot:P20042","uniprot:P06730","uniprot:P08246","uniprot:P01019","uniprot:P01019","uniprot:P01019","uniprot:Q09472","uniprot:P42566","uniprot:P04626","uniprot:P04626","uniprot:P21860","uniprot:O75460","uniprot:O75460","uniprot:O75460","uniprot:P42345","uniprot:Q9UK05","uniprot:P10912","uniprot:Q9UM73","uniprot:P28799","uniprot:P09341","uniprot:P09341","uniprot:Q16665","uniprot:Q16665","uniprot:P09429","uniprot:P11021","uniprot:P11021","uniprot:Q92993","uniprot:Q9HC29","uniprot:P01574","uniprot:P08069","uniprot:O14920","uniprot:Q9Y6K9","uniprot:Q16552","uniprot:P01584","uniprot:P05231","uniprot:P05231","uniprot:P10145","uniprot:P10145","uniprot:Q92835","uniprot:P01308","uniprot:P51617","uniprot:P10914","uniprot:P10914","uniprot:Q14653","uniprot:Q92985","uniprot:Q92985","uniprot:P35568","uniprot:P05412","uniprot:P03952","uniprot:O00505","uniprot:O00629","uniprot:P10275","uniprot:P15514","uniprot:P41159","uniprot:P36406","uniprot:P61586","uniprot:P01374","uniprot:P01374","uniprot:P98171","uniprot:Q15797","uniprot:Q99717","uniprot:O15198","uniprot:Q9UDY8","uniprot:Q92974","uniprot:Q02750","uniprot:Q13163","uniprot:O43318","uniprot:Q16539","uniprot:Q13164","uniprot:P04201","uniprot:P14174","uniprot:P08253","uniprot:P08254","uniprot:P01106","uniprot:Q99836","uniprot:Q99836","uniprot:Q99836","uniprot:Q99836","uniprot:O60934","uniprot:Q16236","uniprot:P15336","uniprot:P18848","uniprot:P46531","uniprot:Q13315","uniprot:P04150","uniprot:Q02297","uniprot:P35658","uniprot:P01178","uniprot:Q13535","uniprot:P98161","uniprot:P14618","uniprot:P29590","uniprot:P14859","uniprot:O75688","uniprot:P62140","uniprot:Q13131","uniprot:P19525","uniprot:P19525","uniprot:P19525","uniprot:O75569","uniprot:P01236","uniprot:Q05397","uniprot:P26022","uniprot:Q9UL19","uniprot:P00797","uniprot:P07949","uniprot:PRO_0000032458","uniprot:PRO_0000032458","uniprot:PRO_0000032458","uniprot:PRO_0000032458","uniprot:P07647","uniprot:P0DTC1","uniprot:P0DTC2","uniprot:P0DTC2","uniprot:P0DTC8","uniprot:P19739","uniprot:P19740","uniprot:P36895","uniprot:P36895","uniprot:Q3TBT3","uniprot:Q8VBY2","uniprot:Q9QY24","uniprot:Q01196","uniprot:Q15672","uniprot:O60885","uniprot:Q96F44","uniprot:O14492","uniprot:Q9NRA0","uniprot:Q9BQE4","uniprot:Q8IWR1","uniprot:P35637","uniprot:P61604","uniprot:P09958","uniprot:P60484","uniprot:P35354","uniprot:PRO_0000449629","uniprot:P12643","uniprot:P48431","uniprot:P40763","uniprot:P25445","uniprot:O14788","uniprot:Q9GZY6","uniprot:Q99497","uniprot:P58753","uniprot:Q8IUC6","uniprot:P15169","uniprot:O14656","uniprot:Q09472","uniprot:P09038","uniprot:Q12778","uniprot:P42345","uniprot:P05019","uniprot:Q06330","uniprot:P22301","uniprot:P01584","uniprot:P02788","uniprot:P27361","uniprot:O00327","uniprot:P08253","uniprot:P52948","uniprot:P01270","uniprot:P01270","uniprot:PRO_0000032458","uniprot:Q13950","uniprot:Q96SB4","uniprot:P42224","uniprot:P42224","uniprot:Q13188","uniprot:P20823","uniprot:P01375","uniprot:P01375","uniprot:P04637","uniprot:P04637","uniprot:Q07021","uniprot:Q93009","uniprot:P30291","uniprot:P13671","uniprot:P13671","uniprot:Q15848","uniprot:Q15848","uniprot:Q9NQC3","uniprot:Q14790","uniprot:P22681","uniprot:Q9NR96","uniprot:Q96RT1","uniprot:P46937","uniprot:Q96F44","uniprot:Q969P5","uniprot:Q9HCE7","uniprot:O95630","uniprot:Q9H0M0","uniprot:Q6SZW1","uniprot:Q8NF91","uniprot:Q96JA1","uniprot:P12830","uniprot:P11802","uniprot:P46527","uniprot:P42771","uniprot:P53999","uniprot:Q9Y3D6","uniprot:P00450","uniprot:Q96FW1","uniprot:Q96FW1","uniprot:Q92793","uniprot:Q96AV8","uniprot:P0DML2","uniprot:P41240","uniprot:Q9NS37","uniprot:Q13363","uniprot:P07711","uniprot:Q9NQC7","uniprot:Q9BRV8","uniprot:Q9BRV8","uniprot:Q9BRV8","uniprot:P09874","uniprot:P09874","uniprot:P09874","uniprot:O94907","uniprot:Q12959","uniprot:Q9Y2E6","uniprot:O00429","uniprot:Q8IZH2","uniprot:P21453","uniprot:P05305","uniprot:P05305","uniprot:O43324","uniprot:P05198","uniprot:Q12778","uniprot:Q12778","uniprot:O14793","uniprot:P49841","uniprot:Q13547","uniprot:Q01628","uniprot:P17936","uniprot:P05231","uniprot:P05231","uniprot:P06213","uniprot:P10914","uniprot:O43474","uniprot:P02788","uniprot:P02788","uniprot:Q16584","uniprot:Q99558","uniprot:Q96PU5","uniprot:P25963","uniprot:P25963","uniprot:Q15818","uniprot:P04150","uniprot:P35658","uniprot:P35658","uniprot:O15294","uniprot:Q15139","uniprot:P07477","uniprot:Q07812","uniprot:Q06124","uniprot:P78406","uniprot:Q04206","uniprot:P14373","uniprot:PRO_0000449630","uniprot:PRO_0000449632","uniprot:A3EX97","uniprot:P0C6U8","uniprot:P0C6X7","uniprot:P0DTC2","uniprot:P0DTC5","uniprot:P0DTC6","uniprot:P0DTC9","uniprot:P0DTC9","uniprot:P19740","uniprot:P19740","uniprot:P19740","uniprot:P55272","uniprot:Q0Q471","uniprot:Q80872","uniprot:P78347","uniprot:P25490","uniprot:P23511","uniprot:P11831","uniprot:P16220","uniprot:O76024","uniprot:Q86TM6","uniprot:P0CG48","uniprot:Q16539","uniprot:P13747","uniprot:P33151","uniprot:Q13438","uniprot:Q14258","uniprot:P78317","uniprot:P53355","uniprot:P41240","uniprot:Q14318","uniprot:Q8N2I9","uniprot:P19438","uniprot:P08047","uniprot:P42765","uniprot:P05067","uniprot:Q8NHY2","uniprot:Q62108","uniprot:Q96RU7","uniprot:Q9NRI5","uniprot:Q9UBS5","uniprot:Q09472","uniprot:Q9Y297","uniprot:P05412","uniprot:Q04206","uniprot:Q9UKB1","uniprot:Q9H6Z9","uniprot:P25963","uniprot:P01100","uniprot:P15336","uniprot:Q9NS37","uniprot:Q15744","uniprot:P49715","uniprot:Q96BI3","uniprot:Q9HC98","uniprot:Q9HCE1","uniprot:Q9UJW3","uniprot:Q9NZ94","uniprot:Q00987","uniprot:Q96KS0","uniprot:P78317","uniprot:Q00403","uniprot:Q92831","uniprot:P20226","uniprot:Q96CN9","uniprot:O15164","uniprot:P13984","uniprot:Q86UP2","uniprot:Q8WYK2","uniprot:P19387","uniprot:P02766","uniprot:O14733","uniprot:P17275","uniprot:P21980","uniprot:P05067","uniprot:P28033","uniprot:O15379","uniprot:P29590","uniprot:O75582","uniprot:Q16512","uniprot:O95817","uniprot:Q15759","uniprot:P49137","uniprot:Q16644","uniprot:Q99956","uniprot:Q05923","uniprot:P35236","uniprot:Q15256","uniprot:O15297","uniprot:P54829","uniprot:Q13547","uniprot:Q9BUB5","uniprot:O15355","uniprot:O43464","uniprot:P15336","uniprot:Q16539","uniprot:Q86UR1","uniprot:Q8IWW6","uniprot:P24385","uniprot:P10636","uniprot:O14543","uniprot:P02686","uniprot:P05067","uniprot:Q15750","uniprot:O60880","uniprot:Q9Z1E4","uniprot:O15524","uniprot:O15379","uniprot:P98170","uniprot:Q13616","uniprot:P07900","uniprot:P45983","uniprot:Q8N2W9","uniprot:Q15796","uniprot:Q13485","uniprot:P24928","uniprot:O43734","uniprot:P22681","uniprot:Q14258","uniprot:Q9Y3I1","uniprot:P27695","uniprot:P46937","uniprot:Q13158","uniprot:P31943","uniprot:Q9BXM7","uniprot:Q06830","uniprot:Q96N67","uniprot:P21453","uniprot:P28066","uniprot:P11234","uniprot:P10721","uniprot:P67775","uniprot:P06400","uniprot:O00410","uniprot:P31749","uniprot:Q05086","uniprot:Q08999","uniprot:Q99558","uniprot:Q14318","uniprot:P28749","uniprot:Q8VCF0","uniprot:P19838","uniprot:Q12933","uniprot:P16333","uniprot:P21580","uniprot:Q8TDY2","uniprot:Q15596","uniprot:Q96CV9","uniprot:Q96AX9","uniprot:P46934","uniprot:O95714","uniprot:P14373","uniprot:P07900","uniprot:Q9Y3C5","uniprot:P62258","uniprot:O94826","uniprot:O43734","uniprot:P43405","uniprot:P07225","uniprot:O15084","uniprot:Q9NRM7","uniprot:Q96KP1","uniprot:P00533","uniprot:Q99PQ2","uniprot:Q9GZQ8","uniprot:O14543","uniprot:Q13277","uniprot:O96018","uniprot:Q96FA3","uniprot:P04629","uniprot:O75665","uniprot:Q15468","uniprot:O14980","uniprot:P03372","uniprot:Q13077","uniprot:Q92630","uniprot:Q9HCE7","uniprot:P53350","uniprot:Q9NWT6","uniprot:Q15011","uniprot:O00463","uniprot:P46937","uniprot:P36894","uniprot:Q9H6Z9","uniprot:P23468","uniprot:Q8TAF3","uniprot:Q8NFZ5","uniprot:Q9Y6W8","uniprot:Q92731","uniprot:Q676U5","uniprot:P19438","uniprot:Q92769","uniprot:Q9UJC3","uniprot:Q8N4C6","uniprot:P23443","uniprot:O75385","uniprot:Q9NQL2","uniprot:O43464","uniprot:Q92600","uniprot:P26651","uniprot:Q8QZS5","uniprot:Q7Z3C6","uniprot:P63208","uniprot:Q13501","uniprot:Q13616","uniprot:Q96SN8","uniprot:Q7Z7A1","uniprot:O00743","uniprot:Q9Y297","uniprot:Q00653","uniprot:P19474","uniprot:Q04206","uniprot:Q08378","uniprot:P25963","uniprot:P49815","uniprot:Q8TEV9","uniprot:Q8N122","uniprot:P02686","uniprot:Q8IXJ6","uniprot:Q9Y230","uniprot:P05067","uniprot:P98170","uniprot:Q06787","uniprot:Q64337","uniprot:Q13546","uniprot:Q9Y572","uniprot:Q12933","uniprot:Q13191","uniprot:Q8N2W9","uniprot:Q8IUC6","uniprot:Q14790","uniprot:O15519","uniprot:O14980","uniprot:Q9HBH9","uniprot:Q96FF9","uniprot:Q8CAQ8","uniprot:Q14258","uniprot:Q9BZR9","uniprot:O00463","uniprot:Q92844","uniprot:Q86XR7","uniprot:P21580","uniprot:P43405","uniprot:Q9H3F6","uniprot:Q9BUZ4","uniprot:Q86X55","uniprot:Q7Z434","uniprot:P01106","uniprot:Q15418","uniprot:Q15349","uniprot:P18654","uniprot:Q16539","uniprot:O95071","uniprot:P51812","uniprot:P35236","uniprot:P36507","uniprot:Q15256","uniprot:P54829","uniprot:P30518","uniprot:P32121","uniprot:P37840","uniprot:P43146","uniprot:Q9UHA4","uniprot:P51452","uniprot:Q15121","uniprot:Q13115","uniprot:P46734","uniprot:P28562","uniprot:Q16828","uniprot:P56524","uniprot:Q16690","uniprot:P78347","uniprot:P33076","uniprot:P34925","uniprot:P49790","uniprot:P04637","uniprot:P49137","uniprot:P29590","uniprot:P38398","uniprot:P46940","uniprot:Q12888","uniprot:P53355","uniprot:P55072","uniprot:Q13444","uniprot:P28482","uniprot:Q9UBN7","uniprot:Q13258","uniprot:P04049","uniprot:Q13233","uniprot:Q96AC1","uniprot:P22314","uniprot:Q16666","uniprot:Q969H0","uniprot:P06756","uniprot:P12931","uniprot:O43521","uniprot:Q92858","uniprot:Q99956","uniprot:Q13202","uniprot:Q5VWX1","uniprot:O75386","uniprot:Q60793","uniprot:Q92731","uniprot:O94992","uniprot:Q8WU20","uniprot:P49915","uniprot:Q9UNE7","uniprot:Q92793","uniprot:P48431","uniprot:P27695","uniprot:Q13619","uniprot:Q8QZY3","uniprot:Q9HBW1","uniprot:P49366","uniprot:Q00613","uniprot:P43354","uniprot:O14901","uniprot:O60716","uniprot:O14965","uniprot:P15056","uniprot:O43683","uniprot:P12830","uniprot:P42771","uniprot:Q8N726","uniprot:Q96QB1","uniprot:P00533","uniprot:P01111","uniprot:P06400","uniprot:Q15831","uniprot:Q15058","uniprot:F7VJQ1","uniprot:P04156","uniprot:P56945","uniprot:Q92905","uniprot:Q9BUB5","uniprot:P05412","uniprot:P02741","uniprot:P35354","uniprot:P15173","uniprot:P28324","uniprot:Q02363","uniprot:Q07889","uniprot:O43464","uniprot:P15336","uniprot:P35568","uniprot:Q9H0C8","uniprot:Q13177","uniprot:P42858","uniprot:O60763","uniprot:P67775","uniprot:Q9UJX2","uniprot:P46695","uniprot:P46379","uniprot:P0DMV8","uniprot:Q13451","uniprot:P11309","uniprot:P08238","uniprot:Q9UIG0","uniprot:P07948","uniprot:Q02763","uniprot:P11021","uniprot:Q12967","uniprot:P19793","uniprot:Q03060","uniprot:P07949","uniprot:Q9H467","uniprot:Q01085","uniprot:P23469","uniprot:Q13418","uniprot:Q92879","uniprot:O75676","uniprot:P49407","uniprot:Q9UQC2","uniprot:P11142","uniprot:P11473","uniprot:P08047","uniprot:Q15742","uniprot:P01100","uniprot:P07900","uniprot:Q9NPA2","uniprot:O43809","uniprot:P07737","uniprot:Q07021","uniprot:Q15648","uniprot:P10636","uniprot:P05106","uniprot:Q8N122","uniprot:O15525","uniprot:P02686","uniprot:Q8N6T7","uniprot:P06213","uniprot:Q9BRX9","uniprot:Q92797","uniprot:P57086","uniprot:P41235","uniprot:O96017","uniprot:P19419","uniprot:Q4VCS5","uniprot:Q8BSK8","uniprot:P11416","uniprot:P62805","uniprot:Q9CQQ4","uniprot:Q9H2X6","uniprot:Q15583","uniprot:Q09472","uniprot:Q92793","uniprot:P40763","uniprot:Q13950","uniprot:Q13485","uniprot:Q04771","uniprot:P18075","uniprot:Q9HCE7","uniprot:Q8N2W9","uniprot:P52926","uniprot:O15054","uniprot:P28482","uniprot:Q9UNE7","uniprot:Q9HAU4","uniprot:Q92765","uniprot:P49336","uniprot:P50613","uniprot:P50750","uniprot:P46937","uniprot:Q9H0M0","uniprot:Q15796","uniprot:P84022","uniprot:O43541","uniprot:P36894","uniprot:P04637","uniprot:Q15797","uniprot:Q96K83","uniprot:P49841","uniprot:P10275","uniprot:P37023","uniprot:O14980","uniprot:Q9UJW3","uniprot:P02545","uniprot:Q9R0G7","uniprot:P28070","uniprot:Q6N021","uniprot:P25054","uniprot:Q9Y2T1","uniprot:O43683","uniprot:P24385","uniprot:P35221","uniprot:Q96QB1","uniprot:P04626","uniprot:Q969H0","uniprot:P40692","uniprot:P43246","uniprot:Q9UIF7","uniprot:P01111","uniprot:Q05209","uniprot:O60603","uniprot:O14640","uniprot:P54792","uniprot:P12755","uniprot:Q02535","uniprot:Q13761","uniprot:Q13547","uniprot:Q8TAD8","uniprot:Q9UNY4","uniprot:Q04721","uniprot:Q01831","uniprot:Q03112","uniprot:P12757","uniprot:O96019","uniprot:Q9UJU2","uniprot:Q96RT1","uniprot:Q99717","uniprot:Q14511","uniprot:P36508","uniprot:O43524","uniprot:P10071","uniprot:O60381","uniprot:Q9UBL3","uniprot:P35658","uniprot:Q8TEW0","uniprot:P26367","uniprot:O00255","uniprot:O14686","uniprot:P0CG48","uniprot:Q9Y3M8","uniprot:O00410","uniprot:P55316","uniprot:P35813","uniprot:P25490","uniprot:P46934","uniprot:O75925","uniprot:P46734","uniprot:Q969G3","uniprot:Q92830","uniprot:O14964","uniprot:O15105","uniprot:Q15831","uniprot:P22670","uniprot:Q8IU81","uniprot:Q14686","uniprot:O75177","uniprot:P05067","uniprot:Q01196","uniprot:O60244","uniprot:Q93008","uniprot:P21675","uniprot:P51610","uniprot:Q9UPZ9","uniprot:Q9ULH7","uniprot:Q15025","uniprot:Q86VP1","uniprot:O14920","uniprot:Q9NS56","uniprot:P29590","uniprot:P14373","uniprot:Q12933","uniprot:Q9Y3C5","uniprot:P07900","uniprot:Q13490","uniprot:Q13489","uniprot:O43734","uniprot:P03372","uniprot:Q9Y4K3","uniprot:P01375","uniprot:P19438","uniprot:Q15084","uniprot:O75116","uniprot:Q99836","uniprot:Q13546","uniprot:Q13451","uniprot:P21580","uniprot:Q7KZF4","uniprot:P11940","uniprot:P55072","uniprot:Q04206","uniprot:P46937","uniprot:P0CG48","uniprot:P25963","uniprot:Q86UP2","uniprot:P02686","uniprot:Q9Y230","uniprot:P30153","uniprot:O14818","uniprot:P98170","uniprot:O75444","uniprot:O75807","uniprot:P04637","uniprot:P05198","uniprot:P18847","uniprot:P18848","uniprot:P35638","uniprot:Q16236","uniprot:Q92793","uniprot:Q9BY44","uniprot:Q9NZJ5","uniprot:P11021","uniprot:Q9NZJ5","drugbank:DB00945","uniprot:P38936","uniprot:P18146","uniprot:P00533","uniprot:P01375","uniprot:P42224","uniprot:Q03135","uniprot:Q04206","uniprot:P01308","uniprot:P01375","uniprot:P05019","uniprot:PRO_0000032458","uniprot:O15111","uniprot:O95786","uniprot:Q13114","uniprot:Q14164","uniprot:Q14653","uniprot:Q5D1E8","uniprot:Q7Z434","uniprot:Q86WV6","uniprot:Q92844","uniprot:Q9NQC7","uniprot:Q9UHD2","uniprot:Q9Y6K9","pubchem.compound:86583374","uniprot:A3EXH1","uniprot:O00206","uniprot:O14980","uniprot:O15111","uniprot:O15455","uniprot:O60603","uniprot:O75385","uniprot:O75815","uniprot:O94826","uniprot:O95786","uniprot:P01574","uniprot:P05161","uniprot:P19474","uniprot:P45984","uniprot:P60484","uniprot:Q01094","uniprot:Q01628","uniprot:Q09472","uniprot:Q12778","uniprot:Q12933","uniprot:Q13114","uniprot:Q13526","uniprot:Q13568","uniprot:Q14164","uniprot:Q14653","uniprot:Q16666","uniprot:Q5D1E8","uniprot:Q7Z434","uniprot:Q80H93","uniprot:Q86WV6","uniprot:Q8IUC6","uniprot:Q92793","uniprot:Q92844","uniprot:Q92985","uniprot:Q9BYM8","uniprot:Q9BYX4","uniprot:Q9NYK1","uniprot:Q9UHD2","uniprot:Q9Y4K3","drugbank:DB00945","uniprot:P27361","uniprot:P27361","uniprot:Q02297","uniprot:Q02750","uniprot:Q03135","drugbank:DB00945","uniprot:P09601","uniprot:P28068","uniprot:Q96EB6","uniprot:Q13635","uniprot:O00206","uniprot:O15455","uniprot:O60260","uniprot:O94782","uniprot:O95786","uniprot:P01375","uniprot:P12931","uniprot:P31749","uniprot:P36406","uniprot:P42345","uniprot:P49841","uniprot:Q13114","uniprot:Q13546","uniprot:Q14164","uniprot:Q14653","uniprot:Q15025","uniprot:Q16666","uniprot:Q5D1E8","uniprot:Q7Z434","uniprot:Q86VP1","uniprot:Q86WV6","uniprot:Q86YT6","uniprot:Q8IUC6","uniprot:Q92844","uniprot:Q92985","uniprot:Q9NQC7","uniprot:Q9NR96","uniprot:Q9UHD2","uniprot:Q9Y2E6","uniprot:Q9Y4K3","uniprot:Q9Y6K9","uniprot:O00206","uniprot:O15455","uniprot:O95786","uniprot:Q13077","uniprot:Q13114","uniprot:Q14653","uniprot:Q9UHD2","uniprot:Q9UMX0","uniprot:Q9Y4K3"],["Clinical Trials DB","Clinical Trials DB","TF analysis","TF analysis","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","INDRA (drugs)","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","Clinical Trials DB","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (drugs)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","Clinical Trials DB","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","Clinical Trials DB","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA)","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI","INDRA (EMMAA), AILANI"]],"container":"<table class=\"display\">\n  <thead>\n    <tr>\n      <th> <\/th>\n      <th>target_symbol<\/th>\n      <th>agent_name<\/th>\n      <th>agent_id<\/th>\n      <th>source<\/th>\n    <\/tr>\n  <\/thead>\n<\/table>","options":{"columnDefs":[{"orderable":false,"targets":0}],"order":[],"autoWidth":false,"orderClasses":false}},"evals":[],"jsHooks":[]}</script>
<!--/html_preserve-->
    write.table(x=match_drug_target, file = "MatchingDrugs/carnival_drugs.tsv", sep = "\t",
      row.names = FALSE, quote = FALSE)

Session Info Details
====================

    ## R version 4.0.4 (2021-02-15)
    ## Platform: x86_64-w64-mingw32/x64 (64-bit)
    ## Running under: Windows 10 x64 (build 19042)
    ## 
    ## Matrix products: default
    ## 
    ## locale:
    ## [1] LC_COLLATE=English_Germany.1252  LC_CTYPE=English_Germany.1252   
    ## [3] LC_MONETARY=English_Germany.1252 LC_NUMERIC=C                    
    ## [5] LC_TIME=English_Germany.1252    
    ## 
    ## attached base packages:
    ## [1] stats     graphics  grDevices utils     datasets  methods   base     
    ## 
    ## other attached packages:
    ## [1] dplyr_1.0.8 DT_0.21    
    ## 
    ## loaded via a namespace (and not attached):
    ##  [1] rstudioapi_0.13   knitr_1.33        magrittr_2.0.1    tidyselect_1.1.2 
    ##  [5] R6_2.5.1          rlang_1.0.1       fansi_1.0.2       stringr_1.4.0    
    ##  [9] tools_4.0.4       webshot_0.5.2     xfun_0.24         utf8_1.2.2       
    ## [13] DBI_1.1.2         cli_3.2.0         jquerylib_0.1.4   crosstalk_1.1.1  
    ## [17] htmltools_0.5.1.1 ellipsis_0.3.2    assertthat_0.2.1  yaml_2.2.1       
    ## [21] digest_0.6.27     tibble_3.1.6      lifecycle_1.0.1   crayon_1.5.0     
    ## [25] purrr_0.3.4       sass_0.4.0        htmlwidgets_1.5.3 vctrs_0.3.8      
    ## [29] glue_1.4.2        evaluate_0.14     rmarkdown_2.9     stringi_1.6.2    
    ## [33] bslib_0.2.5.1     compiler_4.0.4    pillar_1.7.0      generics_0.1.2   
    ## [37] jsonlite_1.7.2    pkgconfig_2.0.3
